@@ -21,7 +21,7 @@ typedef Eo Efl_Config_Global;
  */
 #define EFL_CONFIG_GLOBAL_CLASS efl_config_global_class_get()
 
-EWAPI const Efl_Class *efl_config_global_class_get(void);
+EWAPI const Efl_Class *efl_config_global_class_get(void) EINA_CONST;
 
 #ifdef EFL_CONFIG_GLOBAL_PROTECTED
 /**
