@@ -13,14 +13,14 @@ typedef Eo Efl_Ui_Layout_Part_Content;
 
 
 #endif
-#ifdef EFL_BETA_API_SUPPORT
 /** Elementary layout internal part class
+ *
+ * @since 1.23
  *
  * @ingroup Efl_Ui_Layout_Part_Content
  */
 #define EFL_UI_LAYOUT_PART_CONTENT_CLASS efl_ui_layout_part_content_class_get()
 
-EWAPI const Efl_Class *efl_ui_layout_part_content_class_get(void);
-#endif /* EFL_BETA_API_SUPPORT */
+EWAPI const Efl_Class *efl_ui_layout_part_content_class_get(void) EINA_CONST;
 
 #endif
