@@ -25,7 +25,7 @@ typedef Eo Efl_Ui_Navigation_Bar;
  */
 #define EFL_UI_NAVIGATION_BAR_CLASS efl_ui_navigation_bar_class_get()
 
-EWAPI const Efl_Class *efl_ui_navigation_bar_class_get(void);
+EWAPI const Efl_Class *efl_ui_navigation_bar_class_get(void) EINA_CONST;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #endif
